@@ -34,7 +34,8 @@ GeoIPRecord * _get_record(GeoIP* gi, unsigned long ipnum) {
 	unsigned char *begin_record_buf = NULL;
 	GeoIPRecord * record;
 	int str_length = 0;
-	int j, seek_country;
+	int j;
+        unsigned int seek_country;
 	double latitude = 0, longitude = 0;
 
 	seek_country = _seek_country(gi, ipnum);
@@ -44,7 +45,7 @@ GeoIPRecord * _get_record(GeoIP* gi, unsigned long ipnum) {
 	record = malloc(sizeof(GeoIPRecord));
 	memset(record, 0, sizeof(GeoIPRecord));
 
-	record_pointer = seek_country + (2 * RECORD_LENGTH - 1) * gi->databaseSegments[0];
+	record_pointer = seek_country + (2 * gi->record_length - 1) * gi->databaseSegments[0];
 
 	if (gi->cache == NULL) {
 		fseek(gi->GeoIPDatabase, record_pointer, SEEK_SET);
